==> easyprophet-1.0.5.tar.gz: easyprophet-1.0.5/CHANGELOG.md <==
-   f e a t :   a d d   t o x 
 
 -   d o c s :   a d d   l i c e n s e ,   i s s u e s ,   c o v e r a g e ,   b u i l d   b a d g e s 
 
 -   a d d   p y p i   b a d g e 
 
 -   C r e a t e   C O D E _ O F _ C O N D U C T . m d 
 
 -   d o c s :   c r e a t e   p y u p . i o   c o n f i g   f i l e 
 
 -   U p d a t e   R E A D M E . m d 
 
 -   d o c s :   a d d   c o d e   o f   C o n d u c t   b a d g e 
 
 -   -   f e a t :   a d d   c o v e r a l l   f o r   h i s t o r y   o f   c o d e   c o v e r a g e 
 
 -   f i x :   u p d a t i n g   p a c k a g e s   i n   r e q u i r e m e n t s _ d e v . t x t 
 
 -   f i x :   r e m o v e d   c o n d a   f r o m   t r a v i s . y m l 
 
 -   f e a t :   a d d e d   b a s i c   p y t e s t 
 
 -   d o c s :   a d d e d   r e q u i r e m e n t s _ d e v . t x t 
 
 -   f e a t :   a d d e d   s a m p l e   t e s t _ d u m m y . p y   f i l e 
 
 -   d o c s :   r e l e a s e   v 1 . 0 . 2   w i t h   t a g   &   c h a n g e l o g 
 
 -   d o c s :   a d d e d   C H A N G E L O G . m d 
 
 -   r e l e a s e   v 1 . 0 . 0 
 
 -   P u b l i s h e d   e a s y p r o p h e t _ e s a m p l e x . i p y n b   v 1 
 
 -   C r e a t e d   u s i n g   C o l a b o r a t o r y 
 
 -   r e l e a s e   0 . 1 . 4 
 
 -   c h a n g e   r e p o   n a m e 
 
 -   r e l e a s e   v 0 . 1 . 2 
 
 -   R e l e a s e   v 0 . 0 . 1   o n   p y p y 
 
 -   r e m o v e d   c l a s s i f i e r s 
 
 -   p u b l i s h i n g   f i r s t   p a c k a g e   v e r s i o n 
 
 -   R e p o   i n i t i a l i z e d 
 
 -   M e r g e   r e m o t e - t r a c k i n g   b r a n c h   ' o r i g i n / m a i n '   i n t o   m a i n 
 
 -   A d d e d   G o o g l e   C o l a b 
 
 -   I n i t i a l   c o m m i t 
 
 

==> easyprophet-1.1.2.tar.gz: easyprophet-1.1.2/CHANGELOG.md <==
-   f e a t :   1 . 1 . 0   S w i t c h   f r o m   f b p r o p h e t   t o   p r o p h e t   ( # 4 ) 
 
 -   f i x :   1 . 0 . 7   a d d   s k l e a r n   m e a n _ s q u a r e d _ e r r o r 
 
 -   f e a t :   1 . 0 . 6   M i n o r   u p d a t e s   &   f i x   t o   a d a p t   t o   f b p r o p h e t   0 . 7 
 
 -   d o c s :   u p d a t e d   R E A D M E . m d   a n d   C H A N G E L O G . m d 
 
 -   f e a t :   a d d   t o x 
 
 -   d o c s :   a d d   l i c e n s e ,   i s s u e s ,   c o v e r a g e ,   b u i l d   b a d g e s 
 
 -   M e r g e   r e m o t e - t r a c k i n g   b r a n c h   ' o r i g i n / m a i n '   i n t o   m a i n 
 
 -   M e r g e   b r a n c h   ' o r i g i n / H E A D ' 
 
 -   a d d e d   l i c e n s e   a n d   i s s u e s   b a d g e 
 
 -   a d d   c o v e r a g e   b a d g e   t o   R E A D M E . m d 
 
 -   a d d   b u i l d   s t a t u s   b a d g e   t o   R E A D M E . m d 
 
 -   a d d   p y p i   b a d g e 
 
 -   C r e a t e   C O D E _ O F _ C O N D U C T . m d 
 
 -   d o c s :   c r e a t e   p y u p . i o   c o n f i g   f i l e 
 
 -   U p d a t e   R E A D M E . m d 
 
 -   d o c s :   a d d   c o d e   o f   C o n d u c t   b a d g e 
 
 -   -   f e a t :   a d d   c o v e r a l l   f o r   h i s t o r y   o f   c o d e   c o v e r a g e 
 
 -   f i x :   u p d a t i n g   p a c k a g e s   i n   r e q u i r e m e n t s _ d e v . t x t 
 
 -   f i x :   r e m o v e d   c o n d a   f r o m   t r a v i s . y m l 
 
 -   f e a t :   a d d e d   b a s i c   p y t e s t 
 
 -   d o c s :   a d d e d   r e q u i r e m e n t s _ d e v . t x t 
 
 -   f e a t :   a d d e d   s a m p l e   t e s t _ d u m m y . p y   f i l e 
 
 -   d o c s :   r e l e a s e   v 1 . 0 . 2   w i t h   t a g   &   c h a n g e l o g 
 
 -   d o c s :   a d d e d   C H A N G E L O G . m d 
 
 -   r e l e a s e   v 1 . 0 . 0 
 
 -   P u b l i s h e d   e a s y p r o p h e t _ e s a m p l e x . i p y n b   v 1 
 
 -   C r e a t e d   u s i n g   C o l a b o r a t o r y 
 
 -   r e l e a s e   0 . 1 . 4 
 
 -   c h a n g e   r e p o   n a m e 
 
 -   r e l e a s e   v 0 . 1 . 2 
 
 -   R e l e a s e   v 0 . 0 . 1   o n   p y p y 
 
 -   r e m o v e d   c l a s s i f i e r s 
 
 -   p u b l i s h i n g   f i r s t   p a c k a g e   v e r s i o n 
 
 -   R e p o   i n i t i a l i z e d 
 
 -   M e r g e   r e m o t e - t r a c k i n g   b r a n c h   ' o r i g i n / m a i n '   i n t o   m a i n 
 
 -   A d d e d   G o o g l e   C o l a b 
 
 -   I n i t i a l   c o m m i t 
 
 
